pub struct BackfillJob {
pub table: TableIdent,
pub text_column: String,
pub new_col: VectorColSpec,
pub embed_fn: EmbedFn,
pub batch_size: usize,
pub on_progress: Option<BackfillProgressFn>,
}Expand description
Adds a new vector column to all existing files in a table.
Does not touch files that already have the column (idempotent).
Concurrent new writes (after add_vector_column was called) already include
the column and are also skipped.
Fields
table: TableIdenttext_column: StringColumn in the Parquet files that holds the text to embed.
new_col: VectorColSpecSpecification for the new vector column.
embed_fn: EmbedFnCallable: given a slice of text strings, returns one F32 vector per text.
batch_size: usizeHow many texts to embed per embed_fn call.
on_progress: Option<BackfillProgressFn>Optional progress callback.
Implementations
Sourceimpl BackfillJob
impl BackfillJob
pub async fn run( self, catalog: Arc<dyn CatalogProvider>, store: Arc<dyn Store>, ) -> AilakeResult<()>