Module compaction

Module compaction 

Structs

CompactionConfig
CompactionExecutor
Executes compaction plans: reads N small files, merges them into a single AI-Lake file with a rebuilt index, and commits to the catalog.
CompactionPlanner

Enums

CompactionIndexStrategy
Index strategy for the merged file produced by compaction.
CompactionMode